c           ***************************************************
c              cgetLoginN:  get login name ( <= 8 characters)
c           *************************************************** 
c        +U77 compliler option is needed
c        for the HP compiler.
c        
#undef GENERIC

#if defined DECALPHA
#define GENERIC
#elif defined PCLinux
#define GENERIC
#elif defined PCLinuxIFC64
#define GENERIC
#elif defined (PCLinuxIFC)  || defined (KEKA) || defined (KEKB) 
#define GENERIC
#elif defined MACOSX
#define GENERIC
#elif defined CF_AlphaLinux
#define GENERIC
#endif


#if defined NEXT486
c           ******************** next Absoft  fortran ***************
c           the same one as sun/hp may be usable instead of this.
c
       subroutine cgetLoginN(userid)
        character*(*) userid
 	integer getlogin,  intlogin
        pointer(pu, intlogin)
 	pu=getlogin()
	call copyCstring(intlogin, userid)
       end
       subroutine copyCstring(Cstring, target)
	implicit none
	integer i
	character Cstring(*), target*(*)
	
	target=' '
	do i=1, len(target)
		if(Cstring(i) == char(0) ) exit
		target(i:i)=Cstring(i)
	enddo
       end
#elif defined GENERIC
      subroutine cgetLoginN(userid)
      implicit none
      character*(*) userid
      character*16 user
      character*1 NULL
      integer leng, kgetenv
      NULL = char(0)
      leng = kgetenv("USER"//NULL, user)
      userid = user(1:leng)
      end
#else
c     **************************** sun4/hp ***************************
c       !!!!  for HP you need +U77 compiler option
c
       subroutine cgetLoginN(userid)
c
       character*(*)  userid
       call getlog(userid)
       end
#endif
#ifdef IBMAIX
        subroutine getlog(user)
        character user*(*)
        call getenv('USER',user)
        end
#endif
c
c       easier interface to kgetenv
c
      integer function kgetenv2(envname, envresult)

      character*(*)  envname   ! input.  environment variable name
      character*(*)  envresult ! output. value of hte env. variable.
 
      integer leng, kgetenv, klena
      character*1  NULL
      character*128 path
      NULL = char(0)
      leng = klena(envname)
      if( leng .gt. 0 ) then
         leng = kgetenv( envname(1:leng)//NULL, envresult)
      else
         leng = 0
         envresult = ' '
      endif
      envresult=envresult(1:leng)//" "
      kgetenv2 = leng
      end
      subroutine cqversion(cosv)
      implicit none
#include "Zmanagerp.h"
      character*8::cosv ! output  cosmos version such 7.58; left justified
      character*64::COSMOSTOP
      character*128:: filen
      integer kgetenv2, icon

      if( kgetenv2("COSMOSTOP", COSMOSTOP) == 0 ) then
         write(0,*) " Environmental variable "
         write(0,*) "COSMOSTOP cannot be obtained in cqversion"
         stop
      endif
      filen = trim(COSMOSTOP)//"/Version/version" 
      call copenf(TempDev, filen, icon)
      read(TempDev, '(a)') cosv
      close(TempDev)
      end
